==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-user/lxqt-admin-user_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Paramètres du groupe</translation>
    </message>
    <message>
        <location filename="../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Nom du groupe :</translation>
    </message>
    <message>
        <location filename="../../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <location filename="../../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Identifiant du groupe :</translation>
    </message>
    <message>
        <location filename="../../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Utilisateurs de ce groupe :</translation>
    </message>
    <message>
        <location filename="../../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Le nom du groupe ne doit pas être vide.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Paramétrage des utilisateurs et des groupes</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Utilisateurs</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="56"/>
        <source>Login Name</source>
        <translation>Identifiant</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="61"/>
        <source>User ID</source>
        <translation>ID de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="66"/>
        <source>Full Name</source>
        <translation>Nom complet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="71"/>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="76"/>
        <source>Home Directory</source>
        <translation>Répertoire racine</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Afficher les utilisateurs système (pour utilisateurs avertis)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Groupes</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="108"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="113"/>
        <source>Group ID</source>
        <translation>ID du groupe</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="118"/>
        <source>Members</source>
        <translation>Membres</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="131"/>
        <source>toolBar</source>
        <translation>Barre d&apos;outils</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="158"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="161"/>
        <source>Add new users or groups</source>
        <translation>Ajouter de nouveaux utilisateurs ou groupes</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="170"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="173"/>
        <source>Delete selected item</source>
        <translation>Supprimer l&apos;item sélectionné</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="182"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>edit properties of the selected item</source>
        <translation>Éditer les propriétés de l&apos;item sélectionné</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="194"/>
        <source>Refresh</source>
        <translation>Rafraichir</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="197"/>
        <source>Refresh the lists</source>
        <translation>Rafraichir la liste</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="206"/>
        <source>Change Password</source>
        <translation>Changer le mot de passe</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>Change password for the selected user or group</source>
        <translation>Changer le mot de passe pour l&apos;utilisateur ou le groupe</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="155"/>
        <location filename="../../mainwindow.cpp" line="167"/>
        <location filename="../../mainwindow.cpp" line="188"/>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="155"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Voulez-vous réellement supprimer l&apos;utilisateur sélectionné ?</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="167"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Voulez-vous réellement supprimer le groupe sélectionné ?</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="178"/>
        <source>Input the new password for %1:</source>
        <translation>Saisir le nouveau mot de passe pour %1 :</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="188"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Voulez-vous réellement avoir un mot de passe vide ?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Paramètres de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Identifiant :</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Nom complet :</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>ID de l&apos;utilisateur :</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Groupe principal :</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Groupes</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>L&apos;utilisateur appartient aux groupes suivants :</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Shell de démarrage :</translation>
    </message>
    <message>
        <location filename="../../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Répertoire racine :</translation>
    </message>
    <message>
        <location filename="../../userdialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../userdialog.cpp" line="117"/>
        <source>The user name cannot be empty.</source>
        <translation>Le nom d&apos;utilisateur ne doit pas être vide.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../../usermanager.cpp" line="217"/>
        <source>lxqt-admin-user</source>
        <translation>lxqt-admin-user</translation>
    </message>
    <message>
        <location filename="../../usermanager.cpp" line="218"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;L&apos;action (%1) a échoué:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-admin/lxqt-admin-user/lxqt-admin-user_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Paramètres du groupe</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Nom du groupe :</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Identifiant du groupe :</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Utilisateurs de ce groupe :</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Le nom du groupe ne doit pas être vide.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Paramétrage des utilisateurs et des groupes</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Utilisateurs</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="56"/>
        <source>Login Name</source>
        <translation>Identifiant</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="61"/>
        <source>User ID</source>
        <translation>ID de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="66"/>
        <source>Full Name</source>
        <translation>Nom complet</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="71"/>
        <source>Group</source>
        <translation>Groupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="76"/>
        <source>Home Directory</source>
        <translation>Répertoire racine</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Afficher les utilisateurs système (pour utilisateurs avertis)</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Groupes</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="108"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="113"/>
        <source>Group ID</source>
        <translation>ID du groupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="118"/>
        <source>Members</source>
        <translation>Membres</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="131"/>
        <source>toolBar</source>
        <translation>Barre d&apos;outils</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="158"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="161"/>
        <source>Add new users or groups</source>
        <translation>Ajouter de nouveaux utilisateurs ou groupes</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="170"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Delete selected item</source>
        <translation>Supprimer l&apos;item sélectionné</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="182"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="185"/>
        <source>edit properties of the selected item</source>
        <translation>Éditer les propriétés de l&apos;item sélectionné</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="194"/>
        <source>Refresh</source>
        <translation>Rafraichir</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="197"/>
        <source>Refresh the lists</source>
        <translation>Rafraichir la liste</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="206"/>
        <source>Change Password</source>
        <translation>Changer le mot de passe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="209"/>
        <source>Change password for the selected user or group</source>
        <translation>Changer le mot de passe pour l&apos;utilisateur ou le groupe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="164"/>
        <location filename="../../../mainwindow.cpp" line="176"/>
        <location filename="../../../mainwindow.cpp" line="197"/>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="164"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Voulez-vous réellement supprimer l&apos;utilisateur sélectionné ?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="176"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Voulez-vous réellement supprimer le groupe sélectionné ?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="187"/>
        <source>Input the new password for %1:</source>
        <translation>Saisir le nouveau mot de passe pour %1 :</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="197"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Voulez-vous réellement avoir un mot de passe vide ?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Paramètres de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Identifiant :</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Nom complet :</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>ID de l&apos;utilisateur :</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Groupe principal :</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Groupes</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>L&apos;utilisateur appartient aux groupes suivants :</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Shell de démarrage :</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Répertoire racine :</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>The user name cannot be empty.</source>
        <translation>Le nom d&apos;utilisateur ne doit pas être vide.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../../../usermanager.cpp" line="224"/>
        <source>lxqt-admin-user</source>
        <translation>lxqt-admin-user</translation>
    </message>
    <message>
        <location filename="../../../usermanager.cpp" line="225"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;L&apos;action (%1) a échoué:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
